@@ -1,5 +1,4 @@
 use std::collections::{HashMap, HashSet};
-use std::convert::{Into, TryFrom};
 use std::fmt;
 use std::fmt::{Debug, Error, Formatter};
 use std::hash::Hash;
@@ -16,25 +15,25 @@ use strum::AsStaticStr;
 use tokio::net::TcpStream;
 use tracing::{error, warn};
 
-use near_crypto_v01::{KeyType, PublicKey, SecretKey, Signature};
-use near_primitives_v01::block::{Approval, Block, BlockHeader, GenesisId};
-use near_primitives_v01::hash::{hash, CryptoHash};
-use near_primitives_v01::merkle::combine_hash;
-use near_primitives_v01::network::{AnnounceAccount, PeerId};
-use near_primitives_v01::sharding::{
+use near_crypto::{KeyType, PublicKey, SecretKey, Signature};
+use near_primitives::block::{Approval, Block, BlockHeader, GenesisId};
+use near_primitives::hash::{hash, CryptoHash};
+use near_primitives::merkle::combine_hash;
+use near_primitives::network::{AnnounceAccount, PeerId};
+use near_primitives::sharding::{
     ChunkHash, PartialEncodedChunk, PartialEncodedChunkPart, PartialEncodedChunkV1,
     PartialEncodedChunkWithArcReceipts, ReceiptProof, ShardChunkHeader,
 };
 #[cfg(feature = "sandbox")]
-use near_primitives_v01::state_record::StateRecord;
-use near_primitives_v01::syncing::{
+use near_primitives::state_record::StateRecord;
+use near_primitives::syncing::{
     EpochSyncFinalizationResponse, EpochSyncResponse, ShardStateSyncResponse,
     ShardStateSyncResponseV1,
 };
-use near_primitives_v01::transaction::{ExecutionOutcomeWithIdAndProof, SignedTransaction};
-use near_primitives_v01::types::{AccountId, BlockHeight, BlockReference, EpochId, ShardId};
-use near_primitives_v01::utils::{from_timestamp, to_timestamp};
-use near_primitives_v01::views::{FinalExecutionOutcomeView, QueryRequest, QueryResponse};
+use near_primitives::transaction::{ExecutionOutcomeWithIdAndProof, SignedTransaction};
+use near_primitives::types::{AccountId, BlockHeight, BlockReference, EpochId, ShardId};
+use near_primitives::utils::{from_timestamp, to_timestamp};
+use near_primitives::views::{FinalExecutionOutcomeView, QueryRequest, QueryResponse};
 
 /// Number of hops a message is allowed to travel before being dropped.
 /// This is used to avoid infinite loop because of inconsistent view of the network
@@ -315,7 +314,7 @@ impl Debug for RoutedMessageBody {
     }
 }
 
-#[derive(BorshSerialize, BorshDeserialize, PartialEq, Eq, Clone, Debug)]
+#[derive(BorshSerialize, BorshDeserialize, PartialEq, Eq, Clone, Debug, Hash)]
 pub enum PeerIdOrHash {
     PeerId(PeerId),
     Hash(CryptoHash),
@@ -834,7 +833,7 @@ impl StateResponseInfo {
     }
 }
 
-#[cfg(feature = "adversarial")]
+#[cfg(feature = "test_features")]
 #[derive(Debug)]
 pub enum NetworkAdversarialMessage {
     AdvProduceBlocks(u64, bool),
@@ -855,7 +854,7 @@ pub enum NetworkSandboxMessage {
 
 #[derive(AsStaticStr)]
 pub enum NetworkViewClientMessages {
-    #[cfg(feature = "adversarial")]
+    #[cfg(feature = "test_features")]
     Adversarial(NetworkAdversarialMessage),
 
     /// Transaction status query
